@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
@@ -31,14 +32,15 @@ class Exceptions:
 
 class EC2InstanceConnectClient:
     """
-    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -49,12 +51,12 @@ class EC2InstanceConnectClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
         """
 
     def send_ssh_public_key(
         self, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
     ) -> SendSSHPublicKeyResponseTypeDef:
         """
-        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
         """
